@@ -99,7 +99,7 @@ cyborgNames = {loc("Artur Detour"), loc("Led Heart"), loc("Orlando Boom!"), loc(
 
 cyborgsDif = {2, 2, 2, 2, 2, 2, 2, 2}
 cyborgsHealth = {100, 100, 100, 100, 100, 100, 100, 100}
-cyborgPos = {1765, 1145}
+cyborgHidePos = {1665, 1800}
 cyborgsTeamNum = {4, 3}
 cyborgsNum = 7
 cyborgsPos = {{2893, 1717}, {2958, 1701}, {3027, 1696}, {3096, 1698},
@@ -298,7 +298,7 @@ function SetupWaterAnim()
   table.insert(startAnim, {func = AnimSay, args = {enemy, loc("Why, why, why, why!"), SAY_SHOUT, 4000}})
   table.insert(startAnim, {func = AnimSay, args = {enemy, loc("I grew sick of the oppression! I broke free!"), SAY_SHOUT, 6500}})
   table.insert(startAnim, {func = AnimSay, args = {natives[1], loc("What oppression? You were the most unoppressed member of the tribe!"), SAY_SHOUT, 10000}})
-  table.insert(startAnim, {func = AnimSay, args = {enemy, loc("The opression of the elders, of course!"), SAY_SHOUT, 6500}})
+  table.insert(startAnim, {func = AnimSay, args = {enemy, loc("The oppression of the elders, of course!"), SAY_SHOUT, 6500}})
   if m5DeployedNum == leaksNum then
     table.insert(startAnim, {func = AnimSay, args = {enemy, loc("You should know this more than anyone, Leaks!"), SAY_SHOUT, 7000}})
   elseif m5LeaksDead == 1 then
@@ -342,7 +342,7 @@ function SetupWaterAnimDeployed()
   table.insert(startAnim, {func = AnimSay, args = {enemy, loc("Why, why, why, why!"), SAY_SHOUT, 4000}})
   table.insert(startAnim, {func = AnimSay, args = {enemy, loc("I grew sick of the oppression! I broke free!"), SAY_SHOUT, 6500}})
   table.insert(startAnim, {func = AnimSay, args = {natives[1], loc("What oppression? You were the most unoppressed member of the tribe!"), SAY_SHOUT, 10000}})
-  table.insert(startAnim, {func = AnimSay, args = {enemy, loc("The opression of the elders, of course!"), SAY_SHOUT, 6500}})
+  table.insert(startAnim, {func = AnimSay, args = {enemy, loc("The oppression of the elders, of course!"), SAY_SHOUT, 6500}})
   table.insert(startAnim, {func = AnimSay, args = {enemy, loc("Just look at Leaks, may he rest in peace!"), SAY_SHOUT, 6500}})
   table.insert(startAnim, {func = AnimSay, args = {enemy, loc("We, the youth, have to constantly prove our value."), SAY_SHOUT, 7000}})
   table.insert(startAnim, {func = AnimSay, args = {enemy, loc("We work and work until we sweat blood."), SAY_SHOUT, 5000}})
@@ -491,8 +491,8 @@ function AfterStartAnim()
   SetHealth(SpawnHealthCrate(2207, 44), 25)
   SetHealth(SpawnHealthCrate(519, 1519), 25)
   SetHealth(SpawnHealthCrate(826, 895), 25)
-  SpawnUtilityCrate(701, 1046, amGirder, 3)
-  TurnTimeLeft = TurnTime
+  SpawnSupplyCrate(701, 1046, amGirder, 3)
+  SetTurnTimeLeft(TurnTime)
 end
 
 function SkipAnim(anim)
@@ -513,7 +513,7 @@ function AfterFleeAnim()
   SetGearMessage(CurrentHedgehog, 0)
   HideHedge(enemy)
   ShowMission(loc("Long Live The Queen"), loc("Coward"), loc("The leader escaped. Defeat the rest of the aliens!"), 1, 0)
-  TurnTimeLeft = TurnTime
+  SetTurnTimeLeft(TurnTime)
 end
 
 function AfterLeaderDeadAnim()
@@ -612,9 +612,9 @@ end
 
 function GetVariables()
   progress = tonumber(GetCampaignVar("Progress"))
-  m5DeployedNum = tonumber(GetCampaignVar("M5DeployedNum"))
-  m2Choice = tonumber(GetCampaignVar("M2Choice"))
-  m5Choice = tonumber(GetCampaignVar("M5Choice"))
+  m5DeployedNum = tonumber(GetCampaignVar("M5DeployedNum")) or leaksNum
+  m2Choice = tonumber(GetCampaignVar("M2Choice")) or choiceRefused
+  m5Choice = tonumber(GetCampaignVar("M5Choice")) or choiceEliminate
   m2DenseDead = tonumber(GetCampaignVar("M2DenseDead"))
   m4DenseDead = tonumber(GetCampaignVar("M4DenseDead"))
   m5DenseDead = tonumber(GetCampaignVar("M5DenseDead"))
@@ -688,18 +688,18 @@ function SetupPlace()
     end
   end
 
-  SpawnAmmoCrate(34, 410, amBee, 2)
-  SpawnAmmoCrate(33, 374, amRCPlane, 1)
-  SpawnAmmoCrate(74, 410, amAirAttack, 3)
-  SpawnAmmoCrate(1313, 1481, amBazooka, 8)
-  SpawnAmmoCrate(80, 360, amSniperRifle, 4)
-  SpawnAmmoCrate(1037, 1508, amShotgun, 7)
-  SpawnAmmoCrate(1037, 1472, amMolotov, 3)
-  SpawnAmmoCrate(1146, 1576, amMortar, 8)
+  SpawnSupplyCrate(34, 410, amBee, 2)
+  SpawnSupplyCrate(33, 374, amRCPlane, 1)
+  SpawnSupplyCrate(74, 410, amAirAttack, 3)
+  SpawnSupplyCrate(1313, 1481, amBazooka, 8)
+  SpawnSupplyCrate(80, 360, amSniperRifle, 4)
+  SpawnSupplyCrate(1037, 1508, amShotgun, 7)
+  SpawnSupplyCrate(1037, 1472, amMolotov, 3)
+  SpawnSupplyCrate(1146, 1576, amMortar, 8)
 
-  SpawnUtilityCrate(1147, 1431, amPortalGun, 2)
-  SpawnUtilityCrate(1219, 1542, amRope, 5)
-  SpawnUtilityCrate(1259, 1501, amJetpack, 2)
+  SpawnSupplyCrate(1147, 1431, amPortalGun, 2)
+  SpawnSupplyCrate(1219, 1542, amRope, 5)
+  SpawnSupplyCrate(1259, 1501, amJetpack, 2)
 
   if not nativeAwaitingDeletion then
     AfterSetupPlace()
@@ -723,7 +723,7 @@ function SetupAmmo()
 end
 
 function AddHogs()
-	AddTeam(loc("Natives"), 29439, "Bone", "Island", "HillBilly", "cm_birdy")
+	AddTeam(loc("Natives"), -2, "Bone", "Island", "HillBilly", "cm_birdy")
   for i = 7, 9 do
     natives[i-6] = AddHog(nativeNames[i], 0, 100, nativeHats[i])
     origNatives[i-6] = natives[i-6]
@@ -732,24 +732,23 @@ function AddHogs()
   origNatives[4] = natives[4]
   nativesLeft = nativesNum
 
-  AddTeam(loc("Beep Loopers"), 14483456, "ring", "UFO", "Robot", "cm_cyborg")
+  AddTeam(loc("Beep Loopers"), -1, "ring", "UFO", "Robot", "cm_cyborg")
   for i = 1, cyborgsTeamNum[1] do
     cyborgs[i] = AddHog(cyborgNames[i], cyborgsDif[i], cyborgsHealth[i], "cyborg2")
   end
 
-  AddTeam(loc("Corporationals"), 14483456, "ring", "UFO", "Robot", "cm_cyborg")
+  AddTeam(loc("Corporationals"), -1, "ring", "UFO", "Robot", "cm_cyborg")
   for i = cyborgsTeamNum[1] + 1, cyborgsNum do
     cyborgs[i] = AddHog(cyborgNames[i], cyborgsDif[i], cyborgsHealth[i], "cyborg2")
   end
   cyborgsLeft = cyborgsTeamNum[1] + cyborgsTeamNum[2]
 
-  AddTeam(loc("Leaderbot"), 14483456, "ring", "UFO", "Robot", "cm_cyborg")
+  AddTeam(loc("Leaderbot"), -1, "ring", "UFO", "Robot", "cm_cyborg")
   enemy = AddHog(loc("Name"), 2, 200, "cyborg1")
 
-  AddTeam(loc("011101001"), 14483456, "ring", "UFO", "Robot", "cm_binary")
+  AddTeam(loc("011101001"), -1, "ring", "UFO", "Robot", "cm_binary")
   cyborg = AddHog(loc("Unit 334a$7%;.*"), 0, 200, "cyborg1")
-
-  SetGearPosition(cyborg, 0, 0)
+  SetGearPosition(cyborg, unpack(cyborgHidePos))
 
   for i = 1, nativesNum do
     AnimSetGearPosition(natives[i], unpack(nativePos[i]))
@@ -858,7 +857,7 @@ end
 
 function onNewTurn()
   if AnimInProgress() then
-    TurnTimeLeft = -1
+    SetTurnTimeLeft(MAX_TURN_TIME)
     return
   end
   if GetHogTeamName(CurrentHedgehog) == loc("011101001") then
@@ -869,11 +868,5 @@ end
 function onPrecise()
   if GameTime > 2500 and AnimInProgress() then
     SetAnimSkip(true)
---  else
---    DeleteGear(cyborgs[1])
---    table.remove(cyborgs, 1)
---    if cyborgsLeft == 0 then
---      DeleteGear(enemy)
---    end
   end
 end
